import os.path

__pkg_path___ = os.path.dirname(os.path.abspath(__file__))
# Use Python semantic versioning
# https://packaging.python.org/tutorials/distributing-packages/#semantic-versioning-preferred
__version__ = '1.0.1'
__app_name__ = "PyWEED"
